==> nuage-vsd-sim-5.2.1.tar.gz: nuage-vsd-sim-5.2.1/nuagevsdsim/simentities/nusimnsgateway.py <==
# -*- coding: utf-8 -*-
# BSD 3-Clause License
#
# Copyright (c) 2017, Nokia
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# * Redistributions of source code must retain the above copyright notice, this
#   list of conditions and the following disclaimer.
#
# * Redistributions in binary form must reproduce the above copyright notice,
#   this list of conditions and the following disclaimer in the documentation
#   and/or other materials provided with the distribution.
#
# * Neither the name of the copyright holder nor the names of its
#   contributors may be used to endorse or promote products derived from
#   this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""
NUSimNSGateway
"""
from vspk import v5_0 as vsdk

from nuagevsdsim.simentities.nusimresource import NUSimResource

class NUSimNSGateway(NUSimResource):
    """ Represents a NSGateway

        Notes:
            Represents a Network Service Gateway.
    """

    __vspk_class__ = vsdk.NUNSGateway
    __unique_fields__ = ['externalID']
    __mandatory_fields__ = ['name', 'templateID']
    __default_fields__ = {
        'TCPMSSEnabled': False,
        'TCPMaximumSegmentSize': 1330,
        'TPMStatus': 'UNKNOWN',
        'SSHService': 'INHERITED',
        'lastConfigurationReloadTimestamp': -1,
        'inheritedSSHServiceState': 'ENABLED',
        'configurationReloadState': 'UNKNOWN',
        'configurationStatus': 'UNKNOWN',
        'controlTrafficCOSValue': 7,
        'controlTrafficDSCPValue': 56
    }
    __get_parents__ = ['ducgroup', 'enterprise', 'me', 'nsggroup', 'nsgredundancygroup', 'performancemonitor', 'policyobjectgroup']
    __create_parents__ = ['enterprise']

    def __init__(self):
        super(NUSimNSGateway, self).__init__()

==> nuage-vsd-sim-5.3.3.tar.gz: nuage-vsd-sim-5.3.3/nuagevsdsim/simentities/nusimnsgateway.py <==
# -*- coding: utf-8 -*-
# BSD 3-Clause License
#
# Copyright (c) 2017, Nokia
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# * Redistributions of source code must retain the above copyright notice, this
#   list of conditions and the following disclaimer.
#
# * Redistributions in binary form must reproduce the above copyright notice,
#   this list of conditions and the following disclaimer in the documentation
#   and/or other materials provided with the distribution.
#
# * Neither the name of the copyright holder nor the names of its
#   contributors may be used to endorse or promote products derived from
#   this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""
NUSimNSGateway
"""
from vspk import v5_0 as vsdk

from nuagevsdsim.simentities.nusimresource import NUSimResource

class NUSimNSGateway(NUSimResource):
    """ Represents a NSGateway

        Notes:
            Network Services Gateways are a policy enforcement end-points responsible for the delivery of networking services. NSG access ports/VLANs may be attached to existing host or bridge VPorts.
    """

    __vspk_class__ = vsdk.NUNSGateway
    __unique_fields__ = ['externalID']
    __mandatory_fields__ = ['name', 'templateID']
    __default_fields__ = {
        'TCPMSSEnabled': False,
        'TCPMaximumSegmentSize': 1330,
        'ZFBMatchAttribute': 'NONE',
        'TPMStatus': 'UNKNOWN',
        'SSHService': 'INHERITED',
        'lastConfigurationReloadTimestamp': -1,
        'gatewayConnected': False,
        'networkAcceleration': 'NONE',
        'inheritedSSHServiceState': 'ENABLED',
        'configurationReloadState': 'UNKNOWN',
        'configurationStatus': 'UNKNOWN',
        'controlTrafficCOSValue': 7,
        'controlTrafficDSCPValue': 56
    }
    __get_parents__ = ['ducgroup', 'enterprise', 'me', 'nsggroup', 'nsgredundancygroup', 'policyobjectgroup']
    __create_parents__ = ['ducgroup', 'enterprise', 'me']

    def __init__(self):
        super(NUSimNSGateway, self).__init__()
